"""wideholy — Python SDK for cross-religion scripture search and comparison.

Access 236,866 scripture records across 5 world religions — Christianity,
Islam, Judaism, Hinduism, and Buddhism — through a unified API.

Usage::

    from wideholy.api import WideHoly

    with WideHoly() as client:
        votd = client.verse_of_the_day("bible")
        print(votd["reference"])  # Genesis 1:1

        result = client.compare("bible:genesis.1.1", "quran:al-fatihah.1")
        print(result["verse_a"]["text"])
"""

__version__ = "0.1.1"

__all__ = [
    "__version__",
]
